==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/DistributionOrderedCacheBehaviorForwardedValuesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property cookies The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
 * @property headers Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
 * @property queryString Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior.
 * @property queryStringCacheKeys When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
 */
public data class DistributionOrderedCacheBehaviorForwardedValuesArgs(
    public val cookies: Output<DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs>,
    public val headers: Output<List<String>>? = null,
    public val queryString: Output<Boolean>,
    public val queryStringCacheKeys: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs =
        com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs.builder()
            .cookies(cookies.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .queryString(queryString.applyValue({ args0 -> args0 }))
            .queryStringCacheKeys(
                queryStringCacheKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [DistributionOrderedCacheBehaviorForwardedValuesArgs].
 */
@PulumiTagMarker
public class DistributionOrderedCacheBehaviorForwardedValuesArgsBuilder internal constructor() {
    private var cookies: Output<DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs>? = null

    private var headers: Output<List<String>>? = null

    private var queryString: Output<Boolean>? = null

    private var queryStringCacheKeys: Output<List<String>>? = null

    /**
     * @param value The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
     */
    @JvmName("ochyjualncktrogc")
    public suspend
    fun cookies(`value`: Output<DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs>) {
        this.cookies = value
    }

    /**
     * @param value Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("wrfuyusodebpvkuy")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("runhvttrivqijwcg")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("jfnbgdkvylpwmrrl")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior.
     */
    @JvmName("nlueogdkwoadwsxo")
    public suspend fun queryString(`value`: Output<Boolean>) {
        this.queryString = value
    }

    /**
     * @param value When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("xnfyqdaoakrjsmin")
    public suspend fun queryStringCacheKeys(`value`: Output<List<String>>) {
        this.queryStringCacheKeys = value
    }

    @JvmName("wmpnxlqmcufjrgfg")
    public suspend fun queryStringCacheKeys(vararg values: Output<String>) {
        this.queryStringCacheKeys = Output.all(values.asList())
    }

    /**
     * @param values When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("dsjfhgquamamdqdf")
    public suspend fun queryStringCacheKeys(values: List<Output<String>>) {
        this.queryStringCacheKeys = Output.all(values)
    }

    /**
     * @param value The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
     */
    @JvmName("ybydajrayegebqdp")
    public suspend fun cookies(`value`: DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cookies = mapped
    }

    /**
     * @param argument The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
     */
    @JvmName("tbblxlilatdeaien")
    public suspend
    fun cookies(argument: suspend DistributionOrderedCacheBehaviorForwardedValuesCookiesArgsBuilder.() -> Unit) {
        val toBeMapped =
            DistributionOrderedCacheBehaviorForwardedValuesCookiesArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.cookies = mapped
    }

    /**
     * @param value Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("wcsegwqxdqrlpdfd")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("gmeynxmvrxauyyfd")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior.
     */
    @JvmName("brrasdnaavovlpgv")
    public suspend fun queryString(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryString = mapped
    }

    /**
     * @param value When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("yupwsfvnaaawbxtl")
    public suspend fun queryStringCacheKeys(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryStringCacheKeys = mapped
    }

    /**
     * @param values When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("ictntlcfkgwysksk")
    public suspend fun queryStringCacheKeys(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryStringCacheKeys = mapped
    }

    internal fun build(): DistributionOrderedCacheBehaviorForwardedValuesArgs =
        DistributionOrderedCacheBehaviorForwardedValuesArgs(
            cookies = cookies ?: throw PulumiNullFieldException("cookies"),
            headers = headers,
            queryString = queryString ?: throw PulumiNullFieldException("queryString"),
            queryStringCacheKeys = queryStringCacheKeys,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/DistributionOrderedCacheBehaviorForwardedValuesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property cookies The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
 * @property headers Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
 * @property queryString Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior.
 * @property queryStringCacheKeys When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
 */
public data class DistributionOrderedCacheBehaviorForwardedValuesArgs(
    public val cookies: Output<DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs>,
    public val headers: Output<List<String>>? = null,
    public val queryString: Output<Boolean>,
    public val queryStringCacheKeys: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs =
        com.pulumi.aws.cloudfront.inputs.DistributionOrderedCacheBehaviorForwardedValuesArgs.builder()
            .cookies(cookies.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .queryString(queryString.applyValue({ args0 -> args0 }))
            .queryStringCacheKeys(
                queryStringCacheKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            ).build()
}

/**
 * Builder for [DistributionOrderedCacheBehaviorForwardedValuesArgs].
 */
@PulumiTagMarker
public class DistributionOrderedCacheBehaviorForwardedValuesArgsBuilder internal constructor() {
    private var cookies: Output<DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs>? = null

    private var headers: Output<List<String>>? = null

    private var queryString: Output<Boolean>? = null

    private var queryStringCacheKeys: Output<List<String>>? = null

    /**
     * @param value The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
     */
    @JvmName("ohboqtuohkdjpvjb")
    public suspend fun cookies(`value`: Output<DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs>) {
        this.cookies = value
    }

    /**
     * @param value Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("vtnirlwfycgtutdf")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("xyjpweehdbpdepus")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("ujcmafjmqshtpuuv")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior.
     */
    @JvmName("vltjbkkraapftkrn")
    public suspend fun queryString(`value`: Output<Boolean>) {
        this.queryString = value
    }

    /**
     * @param value When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("kmgaptdkguptseea")
    public suspend fun queryStringCacheKeys(`value`: Output<List<String>>) {
        this.queryStringCacheKeys = value
    }

    @JvmName("jnxyuapjoyuehxoe")
    public suspend fun queryStringCacheKeys(vararg values: Output<String>) {
        this.queryStringCacheKeys = Output.all(values.asList())
    }

    /**
     * @param values When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("rjrsbuxwluooqlhw")
    public suspend fun queryStringCacheKeys(values: List<Output<String>>) {
        this.queryStringCacheKeys = Output.all(values)
    }

    /**
     * @param value The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
     */
    @JvmName("idafxwdwuufxhmae")
    public suspend fun cookies(`value`: DistributionOrderedCacheBehaviorForwardedValuesCookiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cookies = mapped
    }

    /**
     * @param argument The forwarded values cookies that specifies how CloudFront handles cookies (maximum one).
     */
    @JvmName("lsfvljsqvaeyuaiv")
    public suspend fun cookies(argument: suspend DistributionOrderedCacheBehaviorForwardedValuesCookiesArgsBuilder.() -> Unit) {
        val toBeMapped =
            DistributionOrderedCacheBehaviorForwardedValuesCookiesArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.cookies = mapped
    }

    /**
     * @param value Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("wfynnrhyfeotcxet")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values Headers, if any, that you want CloudFront to vary upon for this cache behavior. Specify `*` to include all headers.
     */
    @JvmName("tinlubblncqadrqv")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior.
     */
    @JvmName("nlhhnvswesydahui")
    public suspend fun queryString(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryString = mapped
    }

    /**
     * @param value When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("naagsunmwdygkjxb")
    public suspend fun queryStringCacheKeys(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queryStringCacheKeys = mapped
    }

    /**
     * @param values When specified, along with a value of `true` for `query_string`, all query strings are forwarded, however only the query string keys listed in this argument are cached. When omitted with a value of `true` for `query_string`, all query string keys are cached.
     */
    @JvmName("vtmjxijlfmcmeqhl")
    public suspend fun queryStringCacheKeys(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.queryStringCacheKeys = mapped
    }

    internal fun build(): DistributionOrderedCacheBehaviorForwardedValuesArgs =
        DistributionOrderedCacheBehaviorForwardedValuesArgs(
            cookies = cookies ?: throw PulumiNullFieldException("cookies"),
            headers = headers,
            queryString = queryString ?: throw PulumiNullFieldException("queryString"),
            queryStringCacheKeys = queryStringCacheKeys,
        )
}
